==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/client/HotRodClientEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.client;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodClientEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity, org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.ClientModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.ClientModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity, org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.HotRodClientEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.3-sources.jar: org/keycloak/models/map/storage/hotRod/client/HotRodClientEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.client;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodClientEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity, org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.ClientModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.ClientModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity, org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.client.HotRodClientEntity.HotRodClientEntitySchema.INSTANCE;
    }
}
